@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -12,16 +12,19 @@
 
 """ Gaussian Forces Driver """
 
-from typing import Union, List, Optional, Dict, Any
+from __future__ import annotations
+
+from typing import Any, Optional, Union
 from qiskit_nature import QiskitNatureError
 
 from qiskit_nature.properties.second_quantization.vibrational import (
+    OccupiedModals,
     VibrationalStructureDriverResult,
 )
+import qiskit_nature.optionals as _optionals
 from ...units_type import UnitsType
 from ..vibrational_structure_driver import VibrationalStructureDriver
 from ...molecule import Molecule
-from .gaussian_utils import check_valid
 from .gaussian_log_driver import GaussianLogDriver
 from .gaussian_log_result import GaussianLogResult
 
@@ -44,7 +47,7 @@ class GaussianForcesDriver(VibrationalStructureDriver):
 
     def __init__(
         self,
-        jcf: Union[str, List[str]] = B3YLP_JCF_DEFAULT,
+        jcf: Union[str, list[str]] = B3YLP_JCF_DEFAULT,
         logfile: Optional[str] = None,
         normalize: bool = True,
     ) -> None:
@@ -55,7 +58,7 @@ class GaussianForcesDriver(VibrationalStructureDriver):
                 strings.
             logfile: Instead of a job control file a log as output from running such a file
                 can optionally be given.
-            normalize: Whether to normalize the factors used in creation of the WatsonHamiltonian
+            normalize: Whether to normalize the factors used in creation of the VibrationalEnergy
                  as returned when this driver is run.
 
         Raises:
@@ -75,13 +78,14 @@ class GaussianForcesDriver(VibrationalStructureDriver):
         # If running from a jcf we need Gaussian™ 16 so check if we have a
         # valid install.
         if self._logfile is None:
-            check_valid()
+            _optionals.HAS_GAUSSIAN.require_now("GaussianForcesDriver __init__")
 
     @staticmethod
+    @_optionals.HAS_GAUSSIAN.require_in_call
     def from_molecule(
         molecule: Molecule,
         basis: str = "sto-3g",
-        driver_kwargs: Optional[Dict[str, Any]] = None,
+        driver_kwargs: Optional[dict[str, Any]] = None,
     ) -> "GaussianForcesDriver":
         """
         Args:
@@ -98,7 +102,6 @@ class GaussianForcesDriver(VibrationalStructureDriver):
         """
         # Ignore kwargs parameter for this driver
         del driver_kwargs
-        GaussianForcesDriver.check_installed()
         basis = GaussianForcesDriver.to_driver_basis(basis)
 
         if molecule.units == UnitsType.ANGSTROM:
@@ -130,21 +133,15 @@ class GaussianForcesDriver(VibrationalStructureDriver):
             return "sto-3g"
         return basis
 
-    @staticmethod
-    def check_installed() -> None:
-        """
-        Checks if Gaussian is installed and available
-
-        Raises:
-            MissingOptionalLibraryError: if not installed.
-        """
-        check_valid()
-
     def run(self) -> VibrationalStructureDriverResult:
         if self._logfile is not None:
             glr = GaussianLogResult(self._logfile)
         else:
             glr = GaussianLogDriver(jcf=self._jcf).run()
 
-        watson = glr.get_watson_hamiltonian(self._normalize)
-        return VibrationalStructureDriverResult.from_legacy_driver_result(watson)
+        driver_result = VibrationalStructureDriverResult()
+        driver_result.add_property(glr.get_vibrational_energy(self._normalize))
+        driver_result.num_modes = len(glr.a_to_h_numbering)
+        driver_result.add_property(OccupiedModals())
+
+        return driver_result
