@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2020, 2021.
+# (C) Copyright IBM 2020, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -22,14 +22,14 @@ from test import QiskitNatureTestCase
 
 import numpy as np
 
+import qiskit
 from qiskit import BasicAer
 from qiskit.algorithms import VQE
 from qiskit.algorithms.optimizers import SLSQP, SPSA
 from qiskit.opflow import AerPauliExpectation, PauliExpectation
 from qiskit.test import slow_test
-from qiskit.utils import QuantumInstance, algorithm_globals
+from qiskit.utils import QuantumInstance, algorithm_globals, optionals
 
-from qiskit_nature import settings
 from qiskit_nature.algorithms import (
     GroundStateEigensolver,
     VQEUCCFactory,
@@ -47,6 +47,8 @@ from qiskit_nature.properties.second_quantization.electronic.integrals import (
     TwoBodyElectronicIntegrals,
 )
 from qiskit_nature.transformers.second_quantization.electronic import FreezeCoreTransformer
+from qiskit_nature import settings
+from qiskit_nature.algorithms.initial_points import MP2InitialPoint
 
 
 class TestGroundStateEigensolver(QiskitNatureTestCase):
@@ -114,7 +116,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
 
     def test_vqe_ucc_custom(self):
         """Test custom ansatz in Factory use case"""
-        solver = VQEUCCFactory(QuantumInstance(BasicAer.get_backend("statevector_simulator")))
+        solver = VQEUCCFactory(
+            quantum_instance=QuantumInstance(BasicAer.get_backend("statevector_simulator"))
+        )
         calc = GroundStateEigensolver(self.qubit_converter, solver)
         res = calc.solve(self.electronic_structure_problem)
         self.assertAlmostEqual(res.total_energies[0], self.reference_energy, places=6)
@@ -128,87 +132,80 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         modes = 4
         h_1 = np.eye(modes, dtype=complex)
         h_2 = np.zeros((modes, modes, modes, modes))
-        aux_ops = ElectronicEnergy(
-            [
-                OneBodyElectronicIntegrals(ElectronicBasis.MO, (h_1, None)),
-                TwoBodyElectronicIntegrals(ElectronicBasis.MO, (h_2, None, None, None)),
-            ],
-        ).second_q_ops()
+        aux_ops = list(
+            ElectronicEnergy(
+                [
+                    OneBodyElectronicIntegrals(ElectronicBasis.MO, (h_1, None)),
+                    TwoBodyElectronicIntegrals(ElectronicBasis.MO, (h_2, None, None, None)),
+                ],
+            )
+            .second_q_ops()
+            .values()
+        )
         aux_ops_copy = copy.deepcopy(aux_ops)
 
         _ = calc.solve(self.electronic_structure_problem)
+
         assert all(
             frozenset(a.to_list()) == frozenset(b.to_list()) for a, b in zip(aux_ops, aux_ops_copy)
         )
 
-    def test_dict_based_aux_ops(self):
-        """Test the `test_dict_based_aux_ops` variant"""
-        try:
-            settings.dict_aux_operators = True
-            solver = NumPyMinimumEigensolverFactory()
-            calc = GroundStateEigensolver(self.qubit_converter, solver)
-            res = calc.solve(self.electronic_structure_problem)
-            self.assertAlmostEqual(res.total_energies[0], self.reference_energy, places=6)
-            self.assertTrue(
-                np.all(isinstance(aux_op, dict) for aux_op in res.aux_operator_eigenvalues)
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["ParticleNumber"][0], 2.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["ParticleNumber"][1], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["AngularMomentum"][0], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["AngularMomentum"][1], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["Magnetization"][0], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["Magnetization"][1], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["DipoleMomentX"][0], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["DipoleMomentX"][1], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["DipoleMomentY"][0], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["DipoleMomentY"][1], 0.0, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["DipoleMomentZ"][0], -1.3889487, places=6
-            )
-            self.assertAlmostEqual(
-                res.aux_operator_eigenvalues[0]["DipoleMomentZ"][1], 0.0, places=6
-            )
-        finally:
+    def test_list_based_aux_ops(self):
+        """Test the list based aux ops variant"""
+        msg_ref = (
+            "List-based `aux_operators` are deprecated as of version 0.3.0 and support "
+            "for them will be removed no sooner than 3 months after the release. Instead, "
+            "use dict-based `aux_operators`. You can switch to the dict-based interface "
+            "immediately, by setting `qiskit_nature.settings.dict_aux_operators` to `True`."
+        )
+        with warnings.catch_warnings(record=True) as c_m:
+            warnings.simplefilter("always")
             settings.dict_aux_operators = False
+            try:
+                solver = NumPyMinimumEigensolverFactory()
+                calc = GroundStateEigensolver(self.qubit_converter, solver)
+                res = calc.solve(self.electronic_structure_problem)
+                self.assertAlmostEqual(res.total_energies[0], self.reference_energy, places=6)
+                self.assertTrue(
+                    np.all(isinstance(aux_op, dict) for aux_op in res.aux_operator_eigenvalues)
+                )
+                aux_op_eigenvalue = res.aux_operator_eigenvalues[0]
+                self.assertAlmostEqual(aux_op_eigenvalue[0][0], 2.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[1][1], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[2][0], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[2][1], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[3][0], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[3][1], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[4][0], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[4][1], 0.0, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[5][0], -1.3889487, places=6)
+                self.assertAlmostEqual(aux_op_eigenvalue[5][1], 0.0, places=6)
+            finally:
+                settings.dict_aux_operators = True
+            msg = str(c_m[0].message)
+            self.assertEqual(msg, msg_ref)
 
     def _setup_evaluation_operators(self):
         # first we run a ground state calculation
-        solver = VQEUCCFactory(QuantumInstance(BasicAer.get_backend("statevector_simulator")))
+        solver = VQEUCCFactory(
+            quantum_instance=QuantumInstance(BasicAer.get_backend("statevector_simulator"))
+        )
         calc = GroundStateEigensolver(self.qubit_converter, solver)
         res = calc.solve(self.electronic_structure_problem)
 
         # now we decide that we want to evaluate another operator
         # for testing simplicity, we just use some pre-constructed auxiliary operators
-        _, *aux_ops = self.qubit_converter.convert_match(
-            self.electronic_structure_problem.second_q_ops()
-        )
-        return calc, res, aux_ops
+        second_q_ops = self.electronic_structure_problem.second_q_ops()
+        # Remove main op to leave just aux ops
+        second_q_ops.pop(self.electronic_structure_problem.main_property_name)
+        aux_ops_dict = self.qubit_converter.convert_match(second_q_ops)
+        return calc, res, aux_ops_dict
 
     def test_eval_op_single(self):
         """Test evaluating a single additional operator"""
         calc, res, aux_ops = self._setup_evaluation_operators()
         # we filter the list because in this test we test a single operator evaluation
-        add_aux_op = aux_ops[0][0]
+        add_aux_op = aux_ops["ParticleNumber"][0]
 
         # now we have the ground state calculation evaluate it
         add_aux_op_res = calc.evaluate_operators(res.raw_result.eigenstate, add_aux_op)
@@ -230,7 +227,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         calc, res, aux_ops = self._setup_evaluation_operators()
         # we filter the list because of simplicity
         expected_results = {"number of particles": 2, "s^2": 0, "magnetization": 0}
-        add_aux_op = aux_ops[0:3]
+        add_aux_op = [
+            aux_ops["ParticleNumber"],
+            aux_ops["AngularMomentum"],
+            aux_ops["Magnetization"],
+        ]
 
         # now we have the ground state calculation evaluate them
         add_aux_op_res = calc.evaluate_operators(res.raw_result.eigenstate, add_aux_op)
@@ -244,7 +245,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         calc, res, aux_ops = self._setup_evaluation_operators()
         # we filter the list because of simplicity
         expected_results = {"number of particles": 2, "s^2": 0, "magnetization": 0}
-        add_aux_op = aux_ops[0:3] + [None]
+        add_aux_op = [
+            aux_ops["ParticleNumber"],
+            aux_ops["AngularMomentum"],
+            aux_ops["Magnetization"],
+        ] + [None]
 
         # now we have the ground state calculation evaluate them
         add_aux_op_res = calc.evaluate_operators(res.raw_result.eigenstate, add_aux_op)
@@ -259,7 +264,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         calc, res, aux_ops = self._setup_evaluation_operators()
         # we filter the list because of simplicity
         expected_results = {"number of particles": 2, "s^2": 0, "magnetization": 0}
-        add_aux_op = aux_ops[0:3]
+        add_aux_op = [
+            aux_ops["ParticleNumber"],
+            aux_ops["AngularMomentum"],
+            aux_ops["Magnetization"],
+        ]
         # now we convert it into a dictionary
         add_aux_op = dict(zip(expected_results.keys(), add_aux_op))
 
@@ -274,7 +283,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         calc, res, aux_ops = self._setup_evaluation_operators()
         # we filter the list because of simplicity
         expected_results = {"number of particles": 2, "s^2": 0, "magnetization": 0}
-        add_aux_op = aux_ops[0:3]
+        add_aux_op = [
+            aux_ops["ParticleNumber"],
+            aux_ops["AngularMomentum"],
+            aux_ops["Magnetization"],
+        ]
         # now we convert it into a dictionary
         add_aux_op = dict(zip(expected_results.keys(), add_aux_op))
         add_aux_op["None"] = None
@@ -301,7 +314,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         calc = GroundStateEigensolver(self.qubit_converter, solver)
         res_qasm = calc.solve(self.electronic_structure_problem)
 
-        hamiltonian = self.electronic_structure_problem.second_q_ops()[0]
+        hamiltonian = self.electronic_structure_problem.second_q_ops()[
+            self.electronic_structure_problem.main_property_name
+        ]
         qubit_op = self.qubit_converter.map(hamiltonian)
 
         ansatz = solver.get_solver(self.electronic_structure_problem, self.qubit_converter).ansatz
@@ -310,17 +325,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
 
         self.assertAlmostEqual(res_qasm.eigenenergies[0], mean[0].real)
 
+    @unittest.skipUnless(optionals.HAS_AER, "qiskit-aer is required to run this test")
     def test_eval_op_qasm_aer(self):
         """Regression tests against https://github.com/Qiskit/qiskit-nature/issues/53."""
-        try:
-            # pylint: disable=import-outside-toplevel
-            # pylint: disable=unused-import
-            from qiskit import Aer
 
-            backend = Aer.get_backend("aer_simulator")
-        except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
-            return
+        backend = qiskit.Aer.get_backend("aer_simulator")
 
         solver = VQEUCCFactory(
             optimizer=SLSQP(maxiter=100),
@@ -335,7 +344,9 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         calc = GroundStateEigensolver(self.qubit_converter, solver)
         res_qasm = calc.solve(self.electronic_structure_problem)
 
-        hamiltonian = self.electronic_structure_problem.second_q_ops()[0]
+        hamiltonian = self.electronic_structure_problem.second_q_ops()[
+            self.electronic_structure_problem.main_property_name
+        ]
         qubit_op = self.qubit_converter.map(hamiltonian)
 
         ansatz = solver.get_solver(self.electronic_structure_problem, self.qubit_converter).ansatz
@@ -399,16 +410,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         self.assertAlmostEqual(result.total_energies[0], -1.138, places=2)
 
     @slow_test
+    @unittest.skipUnless(optionals.HAS_AER, "qiskit-aer is required to run this test")
     def test_uccsd_hf_aer_statevector(self):
         """uccsd hf test with Aer statevector"""
-        try:
-            # pylint: disable=import-outside-toplevel
-            from qiskit import Aer
 
-            backend = Aer.get_backend("aer_simulator_statevector")
-        except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
-            return
+        backend = qiskit.Aer.get_backend("aer_simulator_statevector")
 
         ansatz = self._prepare_uccsd_hf(self.qubit_converter)
 
@@ -425,16 +431,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         self.assertAlmostEqual(result.total_energies[0], self.reference_energy, places=6)
 
     @slow_test
+    @unittest.skipUnless(optionals.HAS_AER, "qiskit-aer is required to run this test")
     def test_uccsd_hf_aer_qasm(self):
         """uccsd hf test with Aer qasm simulator."""
-        try:
-            # pylint: disable=import-outside-toplevel
-            from qiskit import Aer
 
-            backend = Aer.get_backend("aer_simulator")
-        except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
-            return
+        backend = qiskit.Aer.get_backend("aer_simulator")
 
         ansatz = self._prepare_uccsd_hf(self.qubit_converter)
 
@@ -456,16 +457,11 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         self.assertAlmostEqual(result.total_energies[0], -1.131, places=2)
 
     @slow_test
+    @unittest.skipUnless(optionals.HAS_AER, "qiskit-aer is required to run this test")
     def test_uccsd_hf_aer_qasm_snapshot(self):
         """uccsd hf test with Aer qasm simulator snapshot."""
-        try:
-            # pylint: disable=import-outside-toplevel
-            from qiskit import Aer
 
-            backend = Aer.get_backend("aer_simulator")
-        except ImportError as ex:  # pylint: disable=broad-except
-            self.skipTest(f"Aer doesn't appear to be installed. Error: '{str(ex)}'")
-            return
+        backend = qiskit.Aer.get_backend("aer_simulator")
 
         ansatz = self._prepare_uccsd_hf(self.qubit_converter)
 
@@ -549,6 +545,48 @@ class TestGroundStateEigensolver(QiskitNatureTestCase):
         for truth, expected in zip(out.getvalue().split("\n"), expected.split("\n")):
             assert truth.strip().startswith(expected.strip())
 
+    def test_default_initial_point(self):
+        """Test when using the default initial point."""
+
+        solver = VQEUCCFactory(
+            quantum_instance=QuantumInstance(BasicAer.get_backend("statevector_simulator"))
+        )
+        calc = GroundStateEigensolver(self.qubit_converter, solver)
+        res = calc.solve(self.electronic_structure_problem)
+
+        np.testing.assert_array_equal(solver.initial_point.to_numpy_array(), [0.0, 0.0, 0.0])
+        self.assertAlmostEqual(res.total_energies[0], self.reference_energy, places=6)
+
+    def test_vqe_ucc_factory_with_user_initial_point(self):
+        """Test VQEUCCFactory when using it with a user defined initial point."""
+
+        initial_point = np.asarray([1.28074029e-19, 5.92226076e-08, 1.11762559e-01])
+        solver = VQEUCCFactory(
+            quantum_instance=QuantumInstance(BasicAer.get_backend("statevector_simulator")),
+            initial_point=initial_point,
+            optimizer=SLSQP(maxiter=1),
+        )
+        calc = GroundStateEigensolver(self.qubit_converter, solver)
+        res = calc.solve(self.electronic_structure_problem)
+        np.testing.assert_array_almost_equal(res.raw_result.optimal_point, initial_point)
+
+    def test_vqe_ucc_factory_with_mp2(self):
+        """Test when using MP2InitialPoint to generate the initial point."""
+
+        informed_start = MP2InitialPoint()
+
+        solver = VQEUCCFactory(
+            quantum_instance=QuantumInstance(BasicAer.get_backend("statevector_simulator")),
+            initial_point=informed_start,
+        )
+        calc = GroundStateEigensolver(self.qubit_converter, solver)
+        res = calc.solve(self.electronic_structure_problem)
+
+        np.testing.assert_array_almost_equal(
+            solver.initial_point.to_numpy_array(), [0.0, 0.0, -0.07197145]
+        )
+        self.assertAlmostEqual(res.total_energies[0], self.reference_energy, places=6)
+
 
 if __name__ == "__main__":
     unittest.main()
